#importation des modules
import numpy as np
import matplotlib.pylab as plt
import csv
import sys

#initialisation du pointage
table = []
#initialisation du temps en seconde
temps = []
#initialisation des abscisses
x = []
#initialisation des ordonnées
y = []

###########################################################
###             IMPORTATION DES DONNES                  ###
###########################################################
#Le fichier csv d'où l'importation des valeurs est effectuée
fichier_importe = 'pointage_centrifugeuse.csv'
#Ne pas modifier les 4 lignes suivantes
with open(fichier_importe, newline='') as csvfile:
    spamreader = csv.reader(csvfile, delimiter=';', quotechar='|')
    for row in spamreader:
        table.append(row)

Dt = 0.200      #pas de temps en s
###########################################################
###                                                     ###
###########################################################

#taille du tableau importée
N = len(table)
M = len(table[0])

#initialisation des constantes du problème
R = 7.00        #Rayon de la centrifugeuse en m
k = 6.26        #constante k en m.s-2
v0 = 16.6       #constante v0 en m.s-1

#Initialisation des vitesses
vx = np.zeros(N-1)       #vitesse calculée selon l'axe des abscisses
vy = np.zeros(N-1)       #vitesse calculée selon l'axe des ordonnées

#Initialisation des accélérations
ax = np.zeros(N-1)       #accélération calculée selon l'axe des abscisses
ay = np.zeros(N-1)       #accélération calculée selon l'axe des ordonnées
at = np.zeros(N-1)      #accélération selon le vecteur unitaire tangent
an = np.zeros(N-1)      #accélération selon le vecteur unitaire normal
anth = np.zeros(N-1)    #accélération selon le vecteur unitaire tangent
atth = np.zeros(N-1)    #accélération selon le vecteur unitaire normal

#Vérification de la structure de ce tableau (3 colonnes ont été exportées : temps, X et Y)
if M != 3 :
    print("Problème dans la réalisation de votre pointage. Reprenez le travail et exportez uniquement deux courbes (Mouvement_X et Mouvement_Y)")
    sys.exit()

#importation des coordonnées X, Y et temps
for i in range(1,N):
    #Génération des listes, avec transformation des données
    temps.append(float(table[i][0].replace(',','.')))
    x.append(float(table[i][1].replace(',','.')))
    y.append(float(table[i][2].replace(',','.')))

#Création d'une fonction permettant de tracer les vecteurs
def trace_vect(x,y,Vectx,Vecty,titre,couleur,position):
    q = plt.quiver(x,y,Vectx,Vecty,color = couleur,width=0.003)
    plt.quiverkey(q, X=0.5, Y=position, U=10,label=titre, labelpos='E', color=couleur)
    
#Calculs approchés des coordonnées des vitesses
for i in range(1,N-2):
    vx[i] = (x[i+1]-x[i-1])/(2*Dt)
    vy[i] = (y[i+1]-y[i-1])/(2*Dt)

#Calculs approchés des coordonnées des accélérations
for i in range(2,N-3):
    ax[i] = (vx[i+1]-vx[i-1])/(2*Dt)
    ay[i] = (vy[i+1]-vy[i-1])/(2*Dt)

#Coordonnées de l'accélération et de la vitesse dans le repère de Frenet
#accélération
at =  np.multiply(ay,x)/R - np.multiply(ax,y)/R
an = - np.multiply(ay,y)/R - np.multiply(ax,x)/R

###########################################################
###         DEBUT DE LA PARTIE A MODIFIER               ###
###########################################################
    
#Calculs théoriques de l'accélération   
for i in range(1,N-1):
    if temps[i] <= 2.65 :
        anth[i] = 0
        atth[i] = 0
    else :
        anth[i] = 0
        atth[i] = 0     

#tracer la norme de l'accélération
plt.plot(temps[2:N-3],an[2:N-3],".",label="an")
#plt.plot(temps[2:N-3],anth[2:N-3],label="anth")
plt.plot(temps[2:N-3],at[2:N-3],".",label="at")
#plt.plot(temps[2:N-3],atth[2:N-3],label="atth")

###########################################################
###         FIN DE LA PARTIE A MODIFIER                 ###
###########################################################
        
#position du bloc légende
plt.legend(loc='upper left')

#étiquettes des axes
plt.xlabel(r'$ t (s)$')
plt.ylabel(r'$ accélération (m/s²)$')

#Titre du graphique
#plt.title('Positions et accélération de la cabine',loc='left')
plt.grid()
plt.show()
